import click
import subprocess
import os, shutil
import glob, ntpath  # for token replace
from funcy import identity
import sys
import questionary

@click.command()
@click.option('--verbose', '-v', is_flag=True, help="Verbose output")
def process(verbose):
    """
    Shallow clones the template, renames and replaces tokens with argument paramters.
    """

    appName = questionary.text("The name of your application? ").ask()
    brand = questionary.select(
        "Brand?",
        choices=[
            'bobswift',
            'wittified',
            'feed3'
        ]).ask()  # returns value of selection
    atlApp = questionary.select(
        "Atlassian App?",
        choices=[
            'confluence',
            'jira'
        ]).ask()  # returns value of selection

    print_func = print if verbose else identity
    print_func("Cloning the Appfire Connect App template...")

    def git(*args):
        return subprocess.check_call(['git'] + list(args))

    git("clone", "git@bitbucket.org:appfire/appfire-connect-app-template.git", "--single-branch")

    dirName = "{}-{}-connect".format(atlApp, appName)

    print_func(f'Renaming template directory root to {dirName}...')
    os.rename('appfire-connect-app-template', dirName)

    print_func(f'Switching working directory to {dirName}...')
    os.chdir(dirName)

    print_func(f'Resetting git...')
    shutil.rmtree(".git")
    git("init")

    print_func(f'Updating template files...')
    for f in glob.glob("*.*"):
        with open(f, "r") as inputfile:
            newText = inputfile.read().replace('xxx', appName).replace('[atl-application]', atlApp).replace('[brand]', brand)

        with open(f, "w") as outputfile:
            outputfile.write(newText)

if __name__ =="__main__":
    process()
